# HyFI Template

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/hyfi-template/branch/main/graph/badge.svg?token=CEUCMPZM9F
[codecov-url]: https://codecov.io/gh/entelecheia/hyfi-template
[pypi-image]: https://img.shields.io/pypi/v/hyfi-template
[license-image]: https://img.shields.io/github/license/entelecheia/hyfi-template
[license-url]: https://github.com/entelecheia/hyfi-template/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/hyfi-template?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/hyfi-template
[release-url]: https://github.com/entelecheia/hyfi-template/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/hyfi-template
[pypi-url]: https://pypi.org/project/hyfi-template
[docs-url]: https://hyfi-template.entelecheia.ai
[changelog]: https://github.com/entelecheia/hyfi-template/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/hyfi-template/blob/main/CONTRIBUTING.md
<!-- Links: -->

A GitHub Template Repository for HyFI-based Projects

- Documentation: [https://hyfi-template.entelecheia.ai][docs-url]
- GitHub: [https://github.com/entelecheia/hyfi-template][repo-url]
- PyPI: [https://pypi.org/project/hyfi-template][pypi-url]

HyFI-Template is a ready-to-use GitHub template repository designed to streamline the process of initializing new projects based on HyFI, a robust framework for building interfaces for Python applications. HyFI leverages the power of the Hydra configuration system and the Pydantic data validation library, offering a comprehensive set of tools to create flexible and adaptable interfaces for various Python projects.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
